@@ -32,16 +32,6 @@
 #include <libgnomeprint/gnome-print-config.h>
 #include <libgnomeprint/gnome-print-config-private.h>
 
-/*
- * I changed GnomePrintConfig form being a boxed type to a GObject,
- * because app developers are going to g_object_unref anyways  Move the
- * following macros to the .h file and make gnome_print_config_[un]ref a macro rather
- * than a function call for GNOME 2.4 (Chema)
- */
-#define GNOME_TYPE_PRINT_CONFIG         (gnome_print_config_get_type ())
-#define GNOME_PRINT_CONFIG(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GNOME_TYPE_PRINT_CONFIG, GnomePrintConfig))
-#define GNOME_IS_PRINT_CONFIG(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNOME_TYPE_PRINT_CONFIG))
-
 typedef struct _GnomePrintConfigClass GnomePrintConfigClass;
 
 struct _GnomePrintConfig {
