@@ -44,6 +44,21 @@ static const GnomePrintUnit gp_units[] = {
 
 #define gp_num_units (sizeof (gp_units) / sizeof (gp_units[0]))
 
+GType
+gnome_print_unit_get_type (void)
+{
+	static GType type = 0;
+	
+	if (type == 0) {
+		type = g_boxed_type_register_static
+			("GnomePrintUnit",
+			 (GBoxedCopyFunc) NULL,
+			 (GBoxedFreeFunc) NULL);
+	}
+
+	return type;
+}
+
 /**
  * gnome_print_unit_get_identity:
  * @base: 
